#!/bin/sh

if [ "$#" != "2" ] ; then
	echo "Usage Info : buildCMInstallDir.sh	<original_CM_Installation_directory> <new_CM_Installation_directory>"
	exit 1
fi

GA_INSTALL_DIR=$1
TARGET_INSTALL_DIR=$2
UPDATEJAR=cm_fix_wasnd.jar

echo "GA_INSTALL_DIR : $GA_INSTALL_DIR"
echo "TARGET_INSTALL_DIR : $TARGET_INSTALL_DIR"
echo "JAVA_HOME : $JAVA_HOME"

# we need Java to call the jar command
if [ "$JAVA_HOME" = ""	] ; then
	echo "please set JAVA_HOME environment variable."
	echo "For example : export JAVA_HOME=/usr/WebSphere/AppServer/java"
	exit 1
fi

# we need Java to call the jar command
if [ ! -f "$JAVA_HOME/bin/jar"	] ; then
	echo "ERROR : $JAVA_HOME/bin/jar does not exist."
	echo "please set JAVA_HOME environment variable."
	echo "For example : export JAVA_HOME=/usr/WebSphere/AppServer/java"
	exit 1
fi

PATH=$JAVA_HOME/bin:$PATH
export PATH


# verify it is the correct source directory
if [ ! -f "$GA_INSTALL_DIR/install_CM" ]; then
	echo "Wrong source directory !"
	echo "The correct directory should contain the file install_CM"
	exit 1
fi

# verify ssdv.jar is in	the current directory
if [ ! -f "./ssdv.jar" ]	; then
	echo "Cannot find ssdv.jar in the current directory"
	echo "You can get it from http://www-1.ibm.com/support/docview.wss?rs=0&uid=swg24010217"
	exit 1
fi

if [ ! -f "$UPDATEJAR" ]	; then
	echo "Cannot find $UPDATEJAR in	the current directory"
	echo "You can get it from http://www-1.ibm.com/support/docview.wss?rs=0&uid=swg24010217"
	exit 1
fi

# create the directory if not already existing
if [ ! -d "$TARGET_INSTALL_DIR" ] ; then
	mkdir "$TARGET_INSTALL_DIR"
fi

# Copy all files from GA_INSTALL_DIR to	TARGET_INSTALL_DIR
cp -Rf $GA_INSTALL_DIR/* $TARGET_INSTALL_DIR/

# Copy ssdv.jar to TARGET_INSTALL_DIR
cp -f ./ssdv.jar $TARGET_INSTALL_DIR/CM83

# Unjar	the fix
CURRENT_DIR=`pwd`
cd $TARGET_INSTALL_DIR/CM83/db2cmv8/config; jar xvf	$CURRENT_DIR/$UPDATEJAR

echo "Creation of the new installation directory is completed"
echo "It's recommended to make a backup	of $TARGET_INSTALL_DIR for future usage."
echo "To Install DB2 Content Manager, run install_CM from $TARGET_INSTALL_DIR."
